from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Media.PlayTo
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class CurrentTimeChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.ICurrentTimeChangeRequestedEventArgs
    _classid_ = 'Windows.Media.PlayTo.CurrentTimeChangeRequestedEventArgs'
    @winrt_mixinmethod
    def get_Time(self: win32more.Windows.Media.PlayTo.ICurrentTimeChangeRequestedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    Time = property(get_Time, None)
class ICurrentTimeChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.ICurrentTimeChangeRequestedEventArgs'
    _iid_ = Guid('{99711324-edc7-4bf5-91f6-3c8627db59e5}')
    @winrt_commethod(6)
    def get_Time(self) -> win32more.Windows.Foundation.TimeSpan: ...
    Time = property(get_Time, None)
class IMuteChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IMuteChangeRequestedEventArgs'
    _iid_ = Guid('{e4b4f5f6-af1f-4f1e-b437-7da32400e1d4}')
    @winrt_commethod(6)
    def get_Mute(self) -> Boolean: ...
    Mute = property(get_Mute, None)
class IPlayToConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToConnection'
    _iid_ = Guid('{112fbfc8-f235-4fde-8d41-9bf27c9e9a40}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.Media.PlayTo.PlayToConnectionState: ...
    @winrt_commethod(7)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToConnection, win32more.Windows.Media.PlayTo.PlayToConnectionStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_Transferred(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToConnection, win32more.Windows.Media.PlayTo.PlayToConnectionTransferredEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_Transferred(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_Error(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToConnection, win32more.Windows.Media.PlayTo.PlayToConnectionErrorEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_Error(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    State = property(get_State, None)
    StateChanged = event()
    Transferred = event()
    Error = event()
class IPlayToConnectionErrorEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToConnectionErrorEventArgs'
    _iid_ = Guid('{bf5eada6-88e6-445f-9d40-d9b9f8939896}')
    @winrt_commethod(6)
    def get_Code(self) -> win32more.Windows.Media.PlayTo.PlayToConnectionError: ...
    @winrt_commethod(7)
    def get_Message(self) -> WinRT_String: ...
    Code = property(get_Code, None)
    Message = property(get_Message, None)
class IPlayToConnectionStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToConnectionStateChangedEventArgs'
    _iid_ = Guid('{68c4b50f-0c20-4980-8602-58c62238d423}')
    @winrt_commethod(6)
    def get_PreviousState(self) -> win32more.Windows.Media.PlayTo.PlayToConnectionState: ...
    @winrt_commethod(7)
    def get_CurrentState(self) -> win32more.Windows.Media.PlayTo.PlayToConnectionState: ...
    CurrentState = property(get_CurrentState, None)
    PreviousState = property(get_PreviousState, None)
class IPlayToConnectionTransferredEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToConnectionTransferredEventArgs'
    _iid_ = Guid('{fae3193a-0683-47d9-8df0-18cbb48984d8}')
    @winrt_commethod(6)
    def get_PreviousSource(self) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_commethod(7)
    def get_CurrentSource(self) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    CurrentSource = property(get_CurrentSource, None)
    PreviousSource = property(get_PreviousSource, None)
class IPlayToManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToManager'
    _iid_ = Guid('{f56a206e-1b77-42ef-8f0d-b949f8d9b260}')
    @winrt_commethod(6)
    def add_SourceRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToManager, win32more.Windows.Media.PlayTo.PlayToSourceRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_SourceRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_SourceSelected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToManager, win32more.Windows.Media.PlayTo.PlayToSourceSelectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_SourceSelected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def put_DefaultSourceSelection(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_DefaultSourceSelection(self) -> Boolean: ...
    DefaultSourceSelection = property(get_DefaultSourceSelection, put_DefaultSourceSelection)
    SourceRequested = event()
    SourceSelected = event()
class IPlayToManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToManagerStatics'
    _iid_ = Guid('{64e6a887-3982-4f3b-ba20-6155e435325b}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.Media.PlayTo.PlayToManager: ...
    @winrt_commethod(7)
    def ShowPlayToUI(self) -> Void: ...
class IPlayToReceiver(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToReceiver'
    _iid_ = Guid('{ac15cf47-a162-4aa6-af1b-3aa35f3b9069}')
    @winrt_commethod(6)
    def add_PlayRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_PlayRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_PauseRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_PauseRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_SourceChangeRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.SourceChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_SourceChangeRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_PlaybackRateChangeRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.PlaybackRateChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_PlaybackRateChangeRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_CurrentTimeChangeRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.CurrentTimeChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_CurrentTimeChangeRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_MuteChangeRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.MuteChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_MuteChangeRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_VolumeChangeRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.VolumeChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_VolumeChangeRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_TimeUpdateRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_TimeUpdateRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_StopRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_StopRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def NotifyVolumeChange(self, volume: Double, mute: Boolean) -> Void: ...
    @winrt_commethod(25)
    def NotifyRateChange(self, rate: Double) -> Void: ...
    @winrt_commethod(26)
    def NotifyLoadedMetadata(self) -> Void: ...
    @winrt_commethod(27)
    def NotifyTimeUpdate(self, currentTime: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(28)
    def NotifyDurationChange(self, duration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(29)
    def NotifySeeking(self) -> Void: ...
    @winrt_commethod(30)
    def NotifySeeked(self) -> Void: ...
    @winrt_commethod(31)
    def NotifyPaused(self) -> Void: ...
    @winrt_commethod(32)
    def NotifyPlaying(self) -> Void: ...
    @winrt_commethod(33)
    def NotifyEnded(self) -> Void: ...
    @winrt_commethod(34)
    def NotifyError(self) -> Void: ...
    @winrt_commethod(35)
    def NotifyStopped(self) -> Void: ...
    @winrt_commethod(36)
    def get_FriendlyName(self) -> WinRT_String: ...
    @winrt_commethod(37)
    def put_FriendlyName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(38)
    def put_SupportsImage(self, value: Boolean) -> Void: ...
    @winrt_commethod(39)
    def get_SupportsImage(self) -> Boolean: ...
    @winrt_commethod(40)
    def put_SupportsAudio(self, value: Boolean) -> Void: ...
    @winrt_commethod(41)
    def get_SupportsAudio(self) -> Boolean: ...
    @winrt_commethod(42)
    def put_SupportsVideo(self, value: Boolean) -> Void: ...
    @winrt_commethod(43)
    def get_SupportsVideo(self) -> Boolean: ...
    @winrt_commethod(44)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_commethod(45)
    def StartAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(46)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    FriendlyName = property(get_FriendlyName, put_FriendlyName)
    Properties = property(get_Properties, None)
    SupportsAudio = property(get_SupportsAudio, put_SupportsAudio)
    SupportsImage = property(get_SupportsImage, put_SupportsImage)
    SupportsVideo = property(get_SupportsVideo, put_SupportsVideo)
    PlayRequested = event()
    PauseRequested = event()
    SourceChangeRequested = event()
    PlaybackRateChangeRequested = event()
    CurrentTimeChangeRequested = event()
    MuteChangeRequested = event()
    VolumeChangeRequested = event()
    TimeUpdateRequested = event()
    StopRequested = event()
class IPlayToSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToSource'
    _iid_ = Guid('{7f138a08-fbb7-4b09-8356-aa5f4e335c31}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.Media.PlayTo.PlayToConnection: ...
    @winrt_commethod(7)
    def get_Next(self) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_commethod(8)
    def put_Next(self, value: win32more.Windows.Media.PlayTo.PlayToSource) -> Void: ...
    @winrt_commethod(9)
    def PlayNext(self) -> Void: ...
    Connection = property(get_Connection, None)
    Next = property(get_Next, put_Next)
class IPlayToSourceDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToSourceDeferral'
    _iid_ = Guid('{4100891d-278e-4f29-859b-a9e501053e7d}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IPlayToSourceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToSourceRequest'
    _iid_ = Guid('{f8584665-64f4-44a0-ac0d-468d2b8fda83}')
    @winrt_commethod(6)
    def get_Deadline(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def DisplayErrorString(self, errorString: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def GetDeferral(self) -> win32more.Windows.Media.PlayTo.PlayToSourceDeferral: ...
    @winrt_commethod(9)
    def SetSource(self, value: win32more.Windows.Media.PlayTo.PlayToSource) -> Void: ...
    Deadline = property(get_Deadline, None)
class IPlayToSourceRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToSourceRequestedEventArgs'
    _iid_ = Guid('{c5cdc330-29df-4ec6-9da9-9fbdfcfc1b3e}')
    @winrt_commethod(6)
    def get_SourceRequest(self) -> win32more.Windows.Media.PlayTo.PlayToSourceRequest: ...
    SourceRequest = property(get_SourceRequest, None)
class IPlayToSourceSelectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs'
    _iid_ = Guid('{0c9d8511-5202-4dcb-8c67-abda12bb3c12}')
    @winrt_commethod(6)
    def get_FriendlyName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Icon(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType: ...
    @winrt_commethod(8)
    def get_SupportsImage(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_SupportsAudio(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_SupportsVideo(self) -> Boolean: ...
    FriendlyName = property(get_FriendlyName, None)
    Icon = property(get_Icon, None)
    SupportsAudio = property(get_SupportsAudio, None)
    SupportsImage = property(get_SupportsImage, None)
    SupportsVideo = property(get_SupportsVideo, None)
class IPlayToSourceWithPreferredSourceUri(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlayToSourceWithPreferredSourceUri'
    _iid_ = Guid('{aab253eb-3301-4dc4-afba-b2f2ed9635a0}')
    @winrt_commethod(6)
    def get_PreferredSourceUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_PreferredSourceUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    PreferredSourceUri = property(get_PreferredSourceUri, put_PreferredSourceUri)
class IPlaybackRateChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IPlaybackRateChangeRequestedEventArgs'
    _iid_ = Guid('{0f5661ae-2c88-4cca-8540-d586095d13a5}')
    @winrt_commethod(6)
    def get_Rate(self) -> Double: ...
    Rate = property(get_Rate, None)
class ISourceChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.ISourceChangeRequestedEventArgs'
    _iid_ = Guid('{fb3f3a96-7aa6-4a8b-86e7-54f6c6d34f64}')
    @winrt_commethod(6)
    def get_Stream(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType: ...
    @winrt_commethod(7)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Author(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Album(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Genre(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_Date(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(13)
    def get_Thumbnail(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(14)
    def get_Rating(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(15)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Album = property(get_Album, None)
    Author = property(get_Author, None)
    Date = property(get_Date, None)
    Description = property(get_Description, None)
    Genre = property(get_Genre, None)
    Properties = property(get_Properties, None)
    Rating = property(get_Rating, None)
    Stream = property(get_Stream, None)
    Thumbnail = property(get_Thumbnail, None)
    Title = property(get_Title, None)
class IVolumeChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.PlayTo.IVolumeChangeRequestedEventArgs'
    _iid_ = Guid('{6f026d5c-cf75-4c2b-913e-6d7c6c329179}')
    @winrt_commethod(6)
    def get_Volume(self) -> Double: ...
    Volume = property(get_Volume, None)
class MuteChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IMuteChangeRequestedEventArgs
    _classid_ = 'Windows.Media.PlayTo.MuteChangeRequestedEventArgs'
    @winrt_mixinmethod
    def get_Mute(self: win32more.Windows.Media.PlayTo.IMuteChangeRequestedEventArgs) -> Boolean: ...
    Mute = property(get_Mute, None)
class PlayToConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToConnection
    _classid_ = 'Windows.Media.PlayTo.PlayToConnection'
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Media.PlayTo.IPlayToConnection) -> win32more.Windows.Media.PlayTo.PlayToConnectionState: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Windows.Media.PlayTo.IPlayToConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToConnection, win32more.Windows.Media.PlayTo.PlayToConnectionStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Windows.Media.PlayTo.IPlayToConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Transferred(self: win32more.Windows.Media.PlayTo.IPlayToConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToConnection, win32more.Windows.Media.PlayTo.PlayToConnectionTransferredEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Transferred(self: win32more.Windows.Media.PlayTo.IPlayToConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Error(self: win32more.Windows.Media.PlayTo.IPlayToConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToConnection, win32more.Windows.Media.PlayTo.PlayToConnectionErrorEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Error(self: win32more.Windows.Media.PlayTo.IPlayToConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    State = property(get_State, None)
    StateChanged = event()
    Transferred = event()
    Error = event()
class PlayToConnectionError(Enum, Int32):
    None_ = 0
    DeviceNotResponding = 1
    DeviceError = 2
    DeviceLocked = 3
    ProtectedPlaybackFailed = 4
class PlayToConnectionErrorEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToConnectionErrorEventArgs
    _classid_ = 'Windows.Media.PlayTo.PlayToConnectionErrorEventArgs'
    @winrt_mixinmethod
    def get_Code(self: win32more.Windows.Media.PlayTo.IPlayToConnectionErrorEventArgs) -> win32more.Windows.Media.PlayTo.PlayToConnectionError: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.Media.PlayTo.IPlayToConnectionErrorEventArgs) -> WinRT_String: ...
    Code = property(get_Code, None)
    Message = property(get_Message, None)
class PlayToConnectionState(Enum, Int32):
    Disconnected = 0
    Connected = 1
    Rendering = 2
class PlayToConnectionStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToConnectionStateChangedEventArgs
    _classid_ = 'Windows.Media.PlayTo.PlayToConnectionStateChangedEventArgs'
    @winrt_mixinmethod
    def get_PreviousState(self: win32more.Windows.Media.PlayTo.IPlayToConnectionStateChangedEventArgs) -> win32more.Windows.Media.PlayTo.PlayToConnectionState: ...
    @winrt_mixinmethod
    def get_CurrentState(self: win32more.Windows.Media.PlayTo.IPlayToConnectionStateChangedEventArgs) -> win32more.Windows.Media.PlayTo.PlayToConnectionState: ...
    CurrentState = property(get_CurrentState, None)
    PreviousState = property(get_PreviousState, None)
class PlayToConnectionTransferredEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToConnectionTransferredEventArgs
    _classid_ = 'Windows.Media.PlayTo.PlayToConnectionTransferredEventArgs'
    @winrt_mixinmethod
    def get_PreviousSource(self: win32more.Windows.Media.PlayTo.IPlayToConnectionTransferredEventArgs) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_mixinmethod
    def get_CurrentSource(self: win32more.Windows.Media.PlayTo.IPlayToConnectionTransferredEventArgs) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    CurrentSource = property(get_CurrentSource, None)
    PreviousSource = property(get_PreviousSource, None)
class PlayToManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToManager
    _classid_ = 'Windows.Media.PlayTo.PlayToManager'
    @winrt_mixinmethod
    def add_SourceRequested(self: win32more.Windows.Media.PlayTo.IPlayToManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToManager, win32more.Windows.Media.PlayTo.PlayToSourceRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SourceRequested(self: win32more.Windows.Media.PlayTo.IPlayToManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SourceSelected(self: win32more.Windows.Media.PlayTo.IPlayToManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToManager, win32more.Windows.Media.PlayTo.PlayToSourceSelectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SourceSelected(self: win32more.Windows.Media.PlayTo.IPlayToManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def put_DefaultSourceSelection(self: win32more.Windows.Media.PlayTo.IPlayToManager, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultSourceSelection(self: win32more.Windows.Media.PlayTo.IPlayToManager) -> Boolean: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.Media.PlayTo.IPlayToManagerStatics) -> win32more.Windows.Media.PlayTo.PlayToManager: ...
    @winrt_classmethod
    def ShowPlayToUI(cls: win32more.Windows.Media.PlayTo.IPlayToManagerStatics) -> Void: ...
    DefaultSourceSelection = property(get_DefaultSourceSelection, put_DefaultSourceSelection)
    SourceRequested = event()
    SourceSelected = event()
class PlayToReceiver(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToReceiver
    _classid_ = 'Windows.Media.PlayTo.PlayToReceiver'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.PlayTo.PlayToReceiver.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.PlayTo.PlayToReceiver: ...
    @winrt_mixinmethod
    def add_PlayRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PlayRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PauseRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PauseRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SourceChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.SourceChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SourceChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PlaybackRateChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.PlaybackRateChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PlaybackRateChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CurrentTimeChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.CurrentTimeChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CurrentTimeChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_MuteChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.MuteChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MuteChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_VolumeChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Media.PlayTo.VolumeChangeRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VolumeChangeRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TimeUpdateRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TimeUpdateRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StopRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.PlayTo.PlayToReceiver, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StopRequested(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def NotifyVolumeChange(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, volume: Double, mute: Boolean) -> Void: ...
    @winrt_mixinmethod
    def NotifyRateChange(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, rate: Double) -> Void: ...
    @winrt_mixinmethod
    def NotifyLoadedMetadata(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifyTimeUpdate(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, currentTime: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def NotifyDurationChange(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, duration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def NotifySeeking(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifySeeked(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifyPaused(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifyPlaying(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifyEnded(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifyError(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def NotifyStopped(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Void: ...
    @winrt_mixinmethod
    def get_FriendlyName(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_FriendlyName(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def put_SupportsImage(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SupportsImage(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Boolean: ...
    @winrt_mixinmethod
    def put_SupportsAudio(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SupportsAudio(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Boolean: ...
    @winrt_mixinmethod
    def put_SupportsVideo(self: win32more.Windows.Media.PlayTo.IPlayToReceiver, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SupportsVideo(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> Boolean: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_mixinmethod
    def StartAsync(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Media.PlayTo.IPlayToReceiver) -> win32more.Windows.Foundation.IAsyncAction: ...
    FriendlyName = property(get_FriendlyName, put_FriendlyName)
    Properties = property(get_Properties, None)
    SupportsAudio = property(get_SupportsAudio, put_SupportsAudio)
    SupportsImage = property(get_SupportsImage, put_SupportsImage)
    SupportsVideo = property(get_SupportsVideo, put_SupportsVideo)
    PlayRequested = event()
    PauseRequested = event()
    SourceChangeRequested = event()
    PlaybackRateChangeRequested = event()
    CurrentTimeChangeRequested = event()
    MuteChangeRequested = event()
    VolumeChangeRequested = event()
    TimeUpdateRequested = event()
    StopRequested = event()
class PlayToSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToSource
    _classid_ = 'Windows.Media.PlayTo.PlayToSource'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.Media.PlayTo.IPlayToSource) -> win32more.Windows.Media.PlayTo.PlayToConnection: ...
    @winrt_mixinmethod
    def get_Next(self: win32more.Windows.Media.PlayTo.IPlayToSource) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_mixinmethod
    def put_Next(self: win32more.Windows.Media.PlayTo.IPlayToSource, value: win32more.Windows.Media.PlayTo.PlayToSource) -> Void: ...
    @winrt_mixinmethod
    def PlayNext(self: win32more.Windows.Media.PlayTo.IPlayToSource) -> Void: ...
    @winrt_mixinmethod
    def get_PreferredSourceUri(self: win32more.Windows.Media.PlayTo.IPlayToSourceWithPreferredSourceUri) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_PreferredSourceUri(self: win32more.Windows.Media.PlayTo.IPlayToSourceWithPreferredSourceUri, value: win32more.Windows.Foundation.Uri) -> Void: ...
    Connection = property(get_Connection, None)
    Next = property(get_Next, put_Next)
    PreferredSourceUri = property(get_PreferredSourceUri, put_PreferredSourceUri)
class PlayToSourceDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToSourceDeferral
    _classid_ = 'Windows.Media.PlayTo.PlayToSourceDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.Media.PlayTo.IPlayToSourceDeferral) -> Void: ...
class PlayToSourceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToSourceRequest
    _classid_ = 'Windows.Media.PlayTo.PlayToSourceRequest'
    @winrt_mixinmethod
    def get_Deadline(self: win32more.Windows.Media.PlayTo.IPlayToSourceRequest) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def DisplayErrorString(self: win32more.Windows.Media.PlayTo.IPlayToSourceRequest, errorString: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Media.PlayTo.IPlayToSourceRequest) -> win32more.Windows.Media.PlayTo.PlayToSourceDeferral: ...
    @winrt_mixinmethod
    def SetSource(self: win32more.Windows.Media.PlayTo.IPlayToSourceRequest, value: win32more.Windows.Media.PlayTo.PlayToSource) -> Void: ...
    Deadline = property(get_Deadline, None)
class PlayToSourceRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToSourceRequestedEventArgs
    _classid_ = 'Windows.Media.PlayTo.PlayToSourceRequestedEventArgs'
    @winrt_mixinmethod
    def get_SourceRequest(self: win32more.Windows.Media.PlayTo.IPlayToSourceRequestedEventArgs) -> win32more.Windows.Media.PlayTo.PlayToSourceRequest: ...
    SourceRequest = property(get_SourceRequest, None)
class PlayToSourceSelectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs
    _classid_ = 'Windows.Media.PlayTo.PlayToSourceSelectedEventArgs'
    @winrt_mixinmethod
    def get_FriendlyName(self: win32more.Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs) -> win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType: ...
    @winrt_mixinmethod
    def get_SupportsImage(self: win32more.Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_SupportsAudio(self: win32more.Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_SupportsVideo(self: win32more.Windows.Media.PlayTo.IPlayToSourceSelectedEventArgs) -> Boolean: ...
    FriendlyName = property(get_FriendlyName, None)
    Icon = property(get_Icon, None)
    SupportsAudio = property(get_SupportsAudio, None)
    SupportsImage = property(get_SupportsImage, None)
    SupportsVideo = property(get_SupportsVideo, None)
class PlaybackRateChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IPlaybackRateChangeRequestedEventArgs
    _classid_ = 'Windows.Media.PlayTo.PlaybackRateChangeRequestedEventArgs'
    @winrt_mixinmethod
    def get_Rate(self: win32more.Windows.Media.PlayTo.IPlaybackRateChangeRequestedEventArgs) -> Double: ...
    Rate = property(get_Rate, None)
class SourceChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs
    _classid_ = 'Windows.Media.PlayTo.SourceChangeRequestedEventArgs'
    @winrt_mixinmethod
    def get_Stream(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Author(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Album(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Genre(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_Thumbnail(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def get_Rating(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Media.PlayTo.ISourceChangeRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Album = property(get_Album, None)
    Author = property(get_Author, None)
    Date = property(get_Date, None)
    Description = property(get_Description, None)
    Genre = property(get_Genre, None)
    Properties = property(get_Properties, None)
    Rating = property(get_Rating, None)
    Stream = property(get_Stream, None)
    Thumbnail = property(get_Thumbnail, None)
    Title = property(get_Title, None)
class VolumeChangeRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.PlayTo.IVolumeChangeRequestedEventArgs
    _classid_ = 'Windows.Media.PlayTo.VolumeChangeRequestedEventArgs'
    @winrt_mixinmethod
    def get_Volume(self: win32more.Windows.Media.PlayTo.IVolumeChangeRequestedEventArgs) -> Double: ...
    Volume = property(get_Volume, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.UserActivities
import win32more.Windows.ApplicationModel.UserActivities.Core
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class CoreUserActivityManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserActivities.Core.CoreUserActivityManager'
    @winrt_classmethod
    def CreateUserActivitySessionInBackground(cls: win32more.Windows.ApplicationModel.UserActivities.Core.ICoreUserActivityManagerStatics, activity: win32more.Windows.ApplicationModel.UserActivities.UserActivity) -> win32more.Windows.ApplicationModel.UserActivities.UserActivitySession: ...
    @winrt_classmethod
    def DeleteUserActivitySessionsInTimeRangeAsync(cls: win32more.Windows.ApplicationModel.UserActivities.Core.ICoreUserActivityManagerStatics, channel: win32more.Windows.ApplicationModel.UserActivities.UserActivityChannel, startTime: win32more.Windows.Foundation.DateTime, endTime: win32more.Windows.Foundation.DateTime) -> win32more.Windows.Foundation.IAsyncAction: ...
class ICoreUserActivityManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserActivities.Core.ICoreUserActivityManagerStatics'
    _iid_ = Guid('{ca3adb02-a4be-4d4d-bfa8-6795f4264efb}')
    @winrt_commethod(6)
    def CreateUserActivitySessionInBackground(self, activity: win32more.Windows.ApplicationModel.UserActivities.UserActivity) -> win32more.Windows.ApplicationModel.UserActivities.UserActivitySession: ...
    @winrt_commethod(7)
    def DeleteUserActivitySessionsInTimeRangeAsync(self, channel: win32more.Windows.ApplicationModel.UserActivities.UserActivityChannel, startTime: win32more.Windows.Foundation.DateTime, endTime: win32more.Windows.Foundation.DateTime) -> win32more.Windows.Foundation.IAsyncAction: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel
import win32more.Windows.ApplicationModel.AppService
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.System
import win32more.Windows.System.RemoteSystems
import win32more.Windows.Win32.System.WinRT
class AppServiceCatalog(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceCatalog'
    @winrt_classmethod
    def FindAppServiceProvidersAsync(cls: win32more.Windows.ApplicationModel.AppService.IAppServiceCatalogStatics, appServiceName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.AppInfo]]: ...
class AppServiceClosedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceClosedEventArgs
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceClosedEventArgs'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.ApplicationModel.AppService.IAppServiceClosedEventArgs) -> win32more.Windows.ApplicationModel.AppService.AppServiceClosedStatus: ...
    Status = property(get_Status, None)
class AppServiceClosedStatus(Enum, Int32):
    Completed = 0
    Canceled = 1
    ResourceLimitsExceeded = 2
    Unknown = 3
class AppServiceConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceConnection'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.AppService.AppServiceConnection.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.AppService.AppServiceConnection: ...
    @winrt_mixinmethod
    def get_AppServiceName(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_AppServiceName(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PackageFamilyName(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PackageFamilyName(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def OpenAsync(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceConnectionStatus]: ...
    @winrt_mixinmethod
    def SendMessageAsync(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, message: win32more.Windows.Foundation.Collections.ValueSet) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceResponse]: ...
    @winrt_mixinmethod
    def add_RequestReceived(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.AppService.AppServiceConnection, win32more.Windows.ApplicationModel.AppService.AppServiceRequestReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RequestReceived(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ServiceClosed(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.AppService.AppServiceConnection, win32more.Windows.ApplicationModel.AppService.AppServiceClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ServiceClosed(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OpenRemoteAsync(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection2, remoteSystemConnectionRequest: win32more.Windows.System.RemoteSystems.RemoteSystemConnectionRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceConnectionStatus]: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection2) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def put_User(self: win32more.Windows.ApplicationModel.AppService.IAppServiceConnection2, value: win32more.Windows.System.User) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def SendStatelessMessageAsync(cls: win32more.Windows.ApplicationModel.AppService.IAppServiceConnectionStatics, connection: win32more.Windows.ApplicationModel.AppService.AppServiceConnection, connectionRequest: win32more.Windows.System.RemoteSystems.RemoteSystemConnectionRequest, message: win32more.Windows.Foundation.Collections.ValueSet) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.StatelessAppServiceResponse]: ...
    AppServiceName = property(get_AppServiceName, put_AppServiceName)
    PackageFamilyName = property(get_PackageFamilyName, put_PackageFamilyName)
    User = property(get_User, put_User)
    RequestReceived = event()
    ServiceClosed = event()
class AppServiceConnectionStatus(Enum, Int32):
    Success = 0
    AppNotInstalled = 1
    AppUnavailable = 2
    AppServiceUnavailable = 3
    Unknown = 4
    RemoteSystemUnavailable = 5
    RemoteSystemNotSupportedByApp = 6
    NotAuthorized = 7
    AuthenticationError = 8
    NetworkNotAvailable = 9
    DisabledByPolicy = 10
    WebServiceUnavailable = 11
class AppServiceDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceDeferral
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.ApplicationModel.AppService.IAppServiceDeferral) -> Void: ...
class AppServiceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceRequest
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceRequest'
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.ApplicationModel.AppService.IAppServiceRequest) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def SendResponseAsync(self: win32more.Windows.ApplicationModel.AppService.IAppServiceRequest, message: win32more.Windows.Foundation.Collections.ValueSet) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceResponseStatus]: ...
    Message = property(get_Message, None)
class AppServiceRequestReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceRequestReceivedEventArgs
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceRequestReceivedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.AppService.IAppServiceRequestReceivedEventArgs) -> win32more.Windows.ApplicationModel.AppService.AppServiceRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.AppService.IAppServiceRequestReceivedEventArgs) -> win32more.Windows.ApplicationModel.AppService.AppServiceDeferral: ...
    Request = property(get_Request, None)
class AppServiceResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceResponse
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceResponse'
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.ApplicationModel.AppService.IAppServiceResponse) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.ApplicationModel.AppService.IAppServiceResponse) -> win32more.Windows.ApplicationModel.AppService.AppServiceResponseStatus: ...
    Message = property(get_Message, None)
    Status = property(get_Status, None)
class AppServiceResponseStatus(Enum, Int32):
    Success = 0
    Failure = 1
    ResourceLimitsExceeded = 2
    Unknown = 3
    RemoteSystemUnavailable = 4
    MessageSizeTooLarge = 5
    AppUnavailable = 6
    AuthenticationError = 7
    NetworkNotAvailable = 8
    DisabledByPolicy = 9
    WebServiceUnavailable = 10
class AppServiceTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails
    _classid_ = 'Windows.ApplicationModel.AppService.AppServiceTriggerDetails'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_CallerPackageFamilyName(self: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppServiceConnection(self: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails) -> win32more.Windows.ApplicationModel.AppService.AppServiceConnection: ...
    @winrt_mixinmethod
    def get_IsRemoteSystemConnection(self: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails2) -> Boolean: ...
    @winrt_mixinmethod
    def CheckCallerForCapabilityAsync(self: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails3, capabilityName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def get_CallerRemoteConnectionToken(self: win32more.Windows.ApplicationModel.AppService.IAppServiceTriggerDetails4) -> WinRT_String: ...
    AppServiceConnection = property(get_AppServiceConnection, None)
    CallerPackageFamilyName = property(get_CallerPackageFamilyName, None)
    CallerRemoteConnectionToken = property(get_CallerRemoteConnectionToken, None)
    IsRemoteSystemConnection = property(get_IsRemoteSystemConnection, None)
    Name = property(get_Name, None)
class IAppServiceCatalogStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceCatalogStatics'
    _iid_ = Guid('{ef0d2507-d132-4c85-8395-3c31d5a1e941}')
    @winrt_commethod(6)
    def FindAppServiceProvidersAsync(self, appServiceName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.AppInfo]]: ...
class IAppServiceClosedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceClosedEventArgs'
    _iid_ = Guid('{de6016f6-cb03-4d35-ac8d-cc6303239731}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.ApplicationModel.AppService.AppServiceClosedStatus: ...
    Status = property(get_Status, None)
class IAppServiceConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceConnection'
    _iid_ = Guid('{9dd474a2-871f-4d52-89a9-9e090531bd27}')
    @winrt_commethod(6)
    def get_AppServiceName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_AppServiceName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_PackageFamilyName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_PackageFamilyName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def OpenAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceConnectionStatus]: ...
    @winrt_commethod(11)
    def SendMessageAsync(self, message: win32more.Windows.Foundation.Collections.ValueSet) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceResponse]: ...
    @winrt_commethod(12)
    def add_RequestReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.AppService.AppServiceConnection, win32more.Windows.ApplicationModel.AppService.AppServiceRequestReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_RequestReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_ServiceClosed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.AppService.AppServiceConnection, win32more.Windows.ApplicationModel.AppService.AppServiceClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_ServiceClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AppServiceName = property(get_AppServiceName, put_AppServiceName)
    PackageFamilyName = property(get_PackageFamilyName, put_PackageFamilyName)
    RequestReceived = event()
    ServiceClosed = event()
class IAppServiceConnection2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceConnection2'
    _iid_ = Guid('{8bdfcd5f-2302-4fbd-8061-52511c2f8bf9}')
    @winrt_commethod(6)
    def OpenRemoteAsync(self, remoteSystemConnectionRequest: win32more.Windows.System.RemoteSystems.RemoteSystemConnectionRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceConnectionStatus]: ...
    @winrt_commethod(7)
    def get_User(self) -> win32more.Windows.System.User: ...
    @winrt_commethod(8)
    def put_User(self, value: win32more.Windows.System.User) -> Void: ...
    User = property(get_User, put_User)
class IAppServiceConnectionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceConnectionStatics'
    _iid_ = Guid('{adc56ce9-d408-5673-8637-827a4b274168}')
    @winrt_commethod(6)
    def SendStatelessMessageAsync(self, connection: win32more.Windows.ApplicationModel.AppService.AppServiceConnection, connectionRequest: win32more.Windows.System.RemoteSystems.RemoteSystemConnectionRequest, message: win32more.Windows.Foundation.Collections.ValueSet) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.StatelessAppServiceResponse]: ...
class IAppServiceDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceDeferral'
    _iid_ = Guid('{7e1b5322-eab0-4248-ae04-fdf93838e472}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IAppServiceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceRequest'
    _iid_ = Guid('{20e58d9d-18de-4b01-80ba-90a76204e3c8}')
    @winrt_commethod(6)
    def get_Message(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def SendResponseAsync(self, message: win32more.Windows.Foundation.Collections.ValueSet) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.AppService.AppServiceResponseStatus]: ...
    Message = property(get_Message, None)
class IAppServiceRequestReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceRequestReceivedEventArgs'
    _iid_ = Guid('{6e122360-ff65-44ae-9e45-857fe4180681}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.AppService.AppServiceRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.ApplicationModel.AppService.AppServiceDeferral: ...
    Request = property(get_Request, None)
class IAppServiceResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceResponse'
    _iid_ = Guid('{8d503cec-9aa3-4e68-9559-9de63e372ce4}')
    @winrt_commethod(6)
    def get_Message(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Windows.ApplicationModel.AppService.AppServiceResponseStatus: ...
    Message = property(get_Message, None)
    Status = property(get_Status, None)
class IAppServiceTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceTriggerDetails'
    _iid_ = Guid('{88a2dcac-ad28-41b8-80bb-bdf1b2169e19}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_CallerPackageFamilyName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AppServiceConnection(self) -> win32more.Windows.ApplicationModel.AppService.AppServiceConnection: ...
    AppServiceConnection = property(get_AppServiceConnection, None)
    CallerPackageFamilyName = property(get_CallerPackageFamilyName, None)
    Name = property(get_Name, None)
class IAppServiceTriggerDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceTriggerDetails2'
    _iid_ = Guid('{e83d54b2-28cc-43f2-b465-c0482e59e2dc}')
    @winrt_commethod(6)
    def get_IsRemoteSystemConnection(self) -> Boolean: ...
    IsRemoteSystemConnection = property(get_IsRemoteSystemConnection, None)
class IAppServiceTriggerDetails3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceTriggerDetails3'
    _iid_ = Guid('{fbd71e21-7939-4e68-9e3c-7780147aabb6}')
    @winrt_commethod(6)
    def CheckCallerForCapabilityAsync(self, capabilityName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IAppServiceTriggerDetails4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IAppServiceTriggerDetails4'
    _iid_ = Guid('{1185b180-8861-5e30-ab55-1cf4d08bbf6d}')
    @winrt_commethod(6)
    def get_CallerRemoteConnectionToken(self) -> WinRT_String: ...
    CallerRemoteConnectionToken = property(get_CallerRemoteConnectionToken, None)
class IStatelessAppServiceResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.AppService.IStatelessAppServiceResponse'
    _iid_ = Guid('{43754af7-a9ec-52fe-82e7-939b68dc9388}')
    @winrt_commethod(6)
    def get_Message(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Windows.ApplicationModel.AppService.StatelessAppServiceResponseStatus: ...
    Message = property(get_Message, None)
    Status = property(get_Status, None)
class StatelessAppServiceResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.AppService.IStatelessAppServiceResponse
    _classid_ = 'Windows.ApplicationModel.AppService.StatelessAppServiceResponse'
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.ApplicationModel.AppService.IStatelessAppServiceResponse) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.ApplicationModel.AppService.IStatelessAppServiceResponse) -> win32more.Windows.ApplicationModel.AppService.StatelessAppServiceResponseStatus: ...
    Message = property(get_Message, None)
    Status = property(get_Status, None)
class StatelessAppServiceResponseStatus(Enum, Int32):
    Success = 0
    AppNotInstalled = 1
    AppUnavailable = 2
    AppServiceUnavailable = 3
    RemoteSystemUnavailable = 4
    RemoteSystemNotSupportedByApp = 5
    NotAuthorized = 6
    ResourceLimitsExceeded = 7
    MessageSizeTooLarge = 8
    Failure = 9
    Unknown = 10
    AuthenticationError = 11
    NetworkNotAvailable = 12
    DisabledByPolicy = 13
    WebServiceUnavailable = 14


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.DataTransfer
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.UI
import win32more.Windows.Web
import win32more.Windows.Web.Http
import win32more.Windows.Web.UI
import win32more.Windows.Win32.System.WinRT
class IWebViewControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControl'
    _iid_ = Guid('{3f921316-bc70-4bda-9136-c94370899fab}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_Source(self, source: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_DocumentTitle(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_CanGoBack(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_CanGoForward(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_DefaultBackgroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(12)
    def get_DefaultBackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(13)
    def get_ContainsFullScreenElement(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_Settings(self) -> win32more.Windows.Web.UI.WebViewControlSettings: ...
    @winrt_commethod(15)
    def get_DeferredPermissionRequests(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Web.UI.WebViewControlDeferredPermissionRequest]: ...
    @winrt_commethod(16)
    def GoForward(self) -> Void: ...
    @winrt_commethod(17)
    def GoBack(self) -> Void: ...
    @winrt_commethod(18)
    def Refresh(self) -> Void: ...
    @winrt_commethod(19)
    def Stop(self) -> Void: ...
    @winrt_commethod(20)
    def Navigate(self, source: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(21)
    def NavigateToString(self, text: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def NavigateToLocalStreamUri(self, source: win32more.Windows.Foundation.Uri, streamResolver: win32more.Windows.Web.IUriToStreamResolver) -> Void: ...
    @winrt_commethod(23)
    def NavigateWithHttpRequestMessage(self, requestMessage: win32more.Windows.Web.Http.HttpRequestMessage) -> Void: ...
    @winrt_commethod(24)
    def InvokeScriptAsync(self, scriptName: WinRT_String, arguments: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_commethod(25)
    def CapturePreviewToStreamAsync(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(26)
    def CaptureSelectedContentToDataPackageAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackage]: ...
    @winrt_commethod(27)
    def BuildLocalStreamUri(self, contentIdentifier: WinRT_String, relativePath: WinRT_String) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(28)
    def GetDeferredPermissionRequestById(self, id: UInt32, result: POINTER(win32more.Windows.Web.UI.WebViewControlDeferredPermissionRequest)) -> Void: ...
    @winrt_commethod(29)
    def add_NavigationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlNavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(30)
    def remove_NavigationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(31)
    def add_ContentLoading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlContentLoadingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(32)
    def remove_ContentLoading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(33)
    def add_DOMContentLoaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlDOMContentLoadedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(34)
    def remove_DOMContentLoaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(35)
    def add_NavigationCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlNavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(36)
    def remove_NavigationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(37)
    def add_FrameNavigationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlNavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(38)
    def remove_FrameNavigationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(39)
    def add_FrameContentLoading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlContentLoadingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(40)
    def remove_FrameContentLoading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(41)
    def add_FrameDOMContentLoaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlDOMContentLoadedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(42)
    def remove_FrameDOMContentLoaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(43)
    def add_FrameNavigationCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlNavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(44)
    def remove_FrameNavigationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(45)
    def add_ScriptNotify(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlScriptNotifyEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(46)
    def remove_ScriptNotify(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(47)
    def add_LongRunningScriptDetected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlLongRunningScriptDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(48)
    def remove_LongRunningScriptDetected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(49)
    def add_UnsafeContentWarningDisplaying(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(50)
    def remove_UnsafeContentWarningDisplaying(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(51)
    def add_UnviewableContentIdentified(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlUnviewableContentIdentifiedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(52)
    def remove_UnviewableContentIdentified(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(53)
    def add_PermissionRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlPermissionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(54)
    def remove_PermissionRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(55)
    def add_UnsupportedUriSchemeIdentified(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlUnsupportedUriSchemeIdentifiedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(56)
    def remove_UnsupportedUriSchemeIdentified(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(57)
    def add_NewWindowRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlNewWindowRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(58)
    def remove_NewWindowRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(59)
    def add_ContainsFullScreenElementChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(60)
    def remove_ContainsFullScreenElementChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(61)
    def add_WebResourceRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.UI.IWebViewControl, win32more.Windows.Web.UI.WebViewControlWebResourceRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(62)
    def remove_WebResourceRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    ContainsFullScreenElement = property(get_ContainsFullScreenElement, None)
    DefaultBackgroundColor = property(get_DefaultBackgroundColor, put_DefaultBackgroundColor)
    DeferredPermissionRequests = property(get_DeferredPermissionRequests, None)
    DocumentTitle = property(get_DocumentTitle, None)
    Settings = property(get_Settings, None)
    Source = property(get_Source, put_Source)
    NavigationStarting = event()
    ContentLoading = event()
    DOMContentLoaded = event()
    NavigationCompleted = event()
    FrameNavigationStarting = event()
    FrameContentLoading = event()
    FrameDOMContentLoaded = event()
    FrameNavigationCompleted = event()
    ScriptNotify = event()
    LongRunningScriptDetected = event()
    UnsafeContentWarningDisplaying = event()
    UnviewableContentIdentified = event()
    PermissionRequested = event()
    UnsupportedUriSchemeIdentified = event()
    NewWindowRequested = event()
    ContainsFullScreenElementChanged = event()
    WebResourceRequested = event()
class IWebViewControl2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControl2'
    _iid_ = Guid('{4d3c06f9-c8df-41cc-8bd5-2a947b204503}')
    @winrt_commethod(6)
    def AddInitializeScript(self, script: WinRT_String) -> Void: ...
class IWebViewControlContentLoadingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlContentLoadingEventArgs'
    _iid_ = Guid('{9a3fccb2-b9bb-404b-a22b-66dccd1250c6}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class IWebViewControlDOMContentLoadedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlDOMContentLoadedEventArgs'
    _iid_ = Guid('{be8bc008-9541-4545-9ff2-2df585b29f7d}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class IWebViewControlDeferredPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlDeferredPermissionRequest'
    _iid_ = Guid('{2ce349e0-d759-445c-9926-8995298f152b}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(8)
    def get_PermissionType(self) -> win32more.Windows.Web.UI.WebViewControlPermissionType: ...
    @winrt_commethod(9)
    def Allow(self) -> Void: ...
    @winrt_commethod(10)
    def Deny(self) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    Uri = property(get_Uri, None)
class IWebViewControlLongRunningScriptDetectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlLongRunningScriptDetectedEventArgs'
    _iid_ = Guid('{2a6e5bba-98b4-45bc-bbeb-0f69ce49c599}')
    @winrt_commethod(6)
    def get_ExecutionTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_StopPageScriptExecution(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_StopPageScriptExecution(self, value: Boolean) -> Void: ...
    ExecutionTime = property(get_ExecutionTime, None)
    StopPageScriptExecution = property(get_StopPageScriptExecution, put_StopPageScriptExecution)
class IWebViewControlNavigationCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlNavigationCompletedEventArgs'
    _iid_ = Guid('{20409918-4a15-4c46-a55d-f79edb0bde8b}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_IsSuccess(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_WebErrorStatus(self) -> win32more.Windows.Web.WebErrorStatus: ...
    IsSuccess = property(get_IsSuccess, None)
    Uri = property(get_Uri, None)
    WebErrorStatus = property(get_WebErrorStatus, None)
class IWebViewControlNavigationStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlNavigationStartingEventArgs'
    _iid_ = Guid('{0c9057c5-0a08-41c7-863b-71e3a9549137}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    Uri = property(get_Uri, None)
class IWebViewControlNewWindowRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs'
    _iid_ = Guid('{3df44bbb-a124-46d5-a083-d02cacdff5ad}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Referrer(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(8)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class IWebViewControlNewWindowRequestedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs2'
    _iid_ = Guid('{b53c5ca6-2aae-4bfc-92b9-c30e92b48098}')
    @winrt_commethod(6)
    def get_NewWindow(self) -> win32more.Windows.Web.UI.IWebViewControl: ...
    @winrt_commethod(7)
    def put_NewWindow(self, value: win32more.Windows.Web.UI.IWebViewControl) -> Void: ...
    @winrt_commethod(8)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    NewWindow = property(get_NewWindow, put_NewWindow)
class IWebViewControlPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlPermissionRequest'
    _iid_ = Guid('{e5bc836c-f22f-40e2-95b2-7729f840eb7f}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(8)
    def get_PermissionType(self) -> win32more.Windows.Web.UI.WebViewControlPermissionType: ...
    @winrt_commethod(9)
    def get_State(self) -> win32more.Windows.Web.UI.WebViewControlPermissionState: ...
    @winrt_commethod(10)
    def Defer(self) -> Void: ...
    @winrt_commethod(11)
    def Allow(self) -> Void: ...
    @winrt_commethod(12)
    def Deny(self) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    State = property(get_State, None)
    Uri = property(get_Uri, None)
class IWebViewControlPermissionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlPermissionRequestedEventArgs'
    _iid_ = Guid('{27204d51-2488-4cc5-968e-0a771e59c147}')
    @winrt_commethod(6)
    def get_PermissionRequest(self) -> win32more.Windows.Web.UI.WebViewControlPermissionRequest: ...
    PermissionRequest = property(get_PermissionRequest, None)
class IWebViewControlScriptNotifyEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlScriptNotifyEventArgs'
    _iid_ = Guid('{491de57b-6f49-41bb-b591-51b85b817037}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Value(self) -> WinRT_String: ...
    Uri = property(get_Uri, None)
    Value = property(get_Value, None)
class IWebViewControlSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlSettings'
    _iid_ = Guid('{c9967fbf-5e98-4cfd-8cce-27b0911e3de8}')
    @winrt_commethod(6)
    def put_IsJavaScriptEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(7)
    def get_IsJavaScriptEnabled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsIndexedDBEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def get_IsIndexedDBEnabled(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsScriptNotifyAllowed(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_IsScriptNotifyAllowed(self) -> Boolean: ...
    IsIndexedDBEnabled = property(get_IsIndexedDBEnabled, put_IsIndexedDBEnabled)
    IsJavaScriptEnabled = property(get_IsJavaScriptEnabled, put_IsJavaScriptEnabled)
    IsScriptNotifyAllowed = property(get_IsScriptNotifyAllowed, put_IsScriptNotifyAllowed)
class IWebViewControlUnsupportedUriSchemeIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlUnsupportedUriSchemeIdentifiedEventArgs'
    _iid_ = Guid('{e3b81944-e4fc-43dc-94ca-f980f30bc51d}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Uri = property(get_Uri, None)
class IWebViewControlUnviewableContentIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlUnviewableContentIdentifiedEventArgs'
    _iid_ = Guid('{4a9680db-88f2-4e20-b693-b4e2df4aa581}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Referrer(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(8)
    def get_MediaType(self) -> WinRT_String: ...
    MediaType = property(get_MediaType, None)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class IWebViewControlWebResourceRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.UI.IWebViewControlWebResourceRequestedEventArgs'
    _iid_ = Guid('{44d6524d-55a4-4d8b-891c-931d8e25d42e}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    @winrt_commethod(7)
    def get_Request(self) -> win32more.Windows.Web.Http.HttpRequestMessage: ...
    @winrt_commethod(8)
    def put_Response(self, value: win32more.Windows.Web.Http.HttpResponseMessage) -> Void: ...
    @winrt_commethod(9)
    def get_Response(self) -> win32more.Windows.Web.Http.HttpResponseMessage: ...
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class WebViewControlContentLoadingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlContentLoadingEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlContentLoadingEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlContentLoadingEventArgs) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class WebViewControlDOMContentLoadedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlDOMContentLoadedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlDOMContentLoadedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlDOMContentLoadedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class WebViewControlDeferredPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlDeferredPermissionRequest
    _classid_ = 'Windows.Web.UI.WebViewControlDeferredPermissionRequest'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Web.UI.IWebViewControlDeferredPermissionRequest) -> UInt32: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlDeferredPermissionRequest) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_PermissionType(self: win32more.Windows.Web.UI.IWebViewControlDeferredPermissionRequest) -> win32more.Windows.Web.UI.WebViewControlPermissionType: ...
    @winrt_mixinmethod
    def Allow(self: win32more.Windows.Web.UI.IWebViewControlDeferredPermissionRequest) -> Void: ...
    @winrt_mixinmethod
    def Deny(self: win32more.Windows.Web.UI.IWebViewControlDeferredPermissionRequest) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    Uri = property(get_Uri, None)
class WebViewControlLongRunningScriptDetectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlLongRunningScriptDetectedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlLongRunningScriptDetectedEventArgs'
    @winrt_mixinmethod
    def get_ExecutionTime(self: win32more.Windows.Web.UI.IWebViewControlLongRunningScriptDetectedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_StopPageScriptExecution(self: win32more.Windows.Web.UI.IWebViewControlLongRunningScriptDetectedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_StopPageScriptExecution(self: win32more.Windows.Web.UI.IWebViewControlLongRunningScriptDetectedEventArgs, value: Boolean) -> Void: ...
    ExecutionTime = property(get_ExecutionTime, None)
    StopPageScriptExecution = property(get_StopPageScriptExecution, put_StopPageScriptExecution)
class WebViewControlNavigationCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlNavigationCompletedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlNavigationCompletedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlNavigationCompletedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_IsSuccess(self: win32more.Windows.Web.UI.IWebViewControlNavigationCompletedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_WebErrorStatus(self: win32more.Windows.Web.UI.IWebViewControlNavigationCompletedEventArgs) -> win32more.Windows.Web.WebErrorStatus: ...
    IsSuccess = property(get_IsSuccess, None)
    Uri = property(get_Uri, None)
    WebErrorStatus = property(get_WebErrorStatus, None)
class WebViewControlNavigationStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlNavigationStartingEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlNavigationStartingEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlNavigationStartingEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.Web.UI.IWebViewControlNavigationStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.Web.UI.IWebViewControlNavigationStartingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    Uri = property(get_Uri, None)
class WebViewControlNewWindowRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlNewWindowRequestedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Referrer(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NewWindow(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs2) -> win32more.Windows.Web.UI.IWebViewControl: ...
    @winrt_mixinmethod
    def put_NewWindow(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs2, value: win32more.Windows.Web.UI.IWebViewControl) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Web.UI.IWebViewControlNewWindowRequestedEventArgs2) -> win32more.Windows.Foundation.Deferral: ...
    Handled = property(get_Handled, put_Handled)
    NewWindow = property(get_NewWindow, put_NewWindow)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class WebViewControlPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlPermissionRequest
    _classid_ = 'Windows.Web.UI.WebViewControlPermissionRequest'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> UInt32: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_PermissionType(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> win32more.Windows.Web.UI.WebViewControlPermissionType: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> win32more.Windows.Web.UI.WebViewControlPermissionState: ...
    @winrt_mixinmethod
    def Defer(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> Void: ...
    @winrt_mixinmethod
    def Allow(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> Void: ...
    @winrt_mixinmethod
    def Deny(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequest) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    State = property(get_State, None)
    Uri = property(get_Uri, None)
class WebViewControlPermissionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlPermissionRequestedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlPermissionRequestedEventArgs'
    @winrt_mixinmethod
    def get_PermissionRequest(self: win32more.Windows.Web.UI.IWebViewControlPermissionRequestedEventArgs) -> win32more.Windows.Web.UI.WebViewControlPermissionRequest: ...
    PermissionRequest = property(get_PermissionRequest, None)
class WebViewControlPermissionState(Enum, Int32):
    Unknown = 0
    Defer = 1
    Allow = 2
    Deny = 3
class WebViewControlPermissionType(Enum, Int32):
    Geolocation = 0
    UnlimitedIndexedDBQuota = 1
    Media = 2
    PointerLock = 3
    WebNotifications = 4
    Screen = 5
    ImmersiveView = 6
class WebViewControlScriptNotifyEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlScriptNotifyEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlScriptNotifyEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlScriptNotifyEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Web.UI.IWebViewControlScriptNotifyEventArgs) -> WinRT_String: ...
    Uri = property(get_Uri, None)
    Value = property(get_Value, None)
class WebViewControlSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlSettings
    _classid_ = 'Windows.Web.UI.WebViewControlSettings'
    @winrt_mixinmethod
    def put_IsJavaScriptEnabled(self: win32more.Windows.Web.UI.IWebViewControlSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsJavaScriptEnabled(self: win32more.Windows.Web.UI.IWebViewControlSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIndexedDBEnabled(self: win32more.Windows.Web.UI.IWebViewControlSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsIndexedDBEnabled(self: win32more.Windows.Web.UI.IWebViewControlSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsScriptNotifyAllowed(self: win32more.Windows.Web.UI.IWebViewControlSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsScriptNotifyAllowed(self: win32more.Windows.Web.UI.IWebViewControlSettings) -> Boolean: ...
    IsIndexedDBEnabled = property(get_IsIndexedDBEnabled, put_IsIndexedDBEnabled)
    IsJavaScriptEnabled = property(get_IsJavaScriptEnabled, put_IsJavaScriptEnabled)
    IsScriptNotifyAllowed = property(get_IsScriptNotifyAllowed, put_IsScriptNotifyAllowed)
class WebViewControlUnsupportedUriSchemeIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlUnsupportedUriSchemeIdentifiedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlUnsupportedUriSchemeIdentifiedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlUnsupportedUriSchemeIdentifiedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.Web.UI.IWebViewControlUnsupportedUriSchemeIdentifiedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.Web.UI.IWebViewControlUnsupportedUriSchemeIdentifiedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Uri = property(get_Uri, None)
class WebViewControlUnviewableContentIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlUnviewableContentIdentifiedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlUnviewableContentIdentifiedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Web.UI.IWebViewControlUnviewableContentIdentifiedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Referrer(self: win32more.Windows.Web.UI.IWebViewControlUnviewableContentIdentifiedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_MediaType(self: win32more.Windows.Web.UI.IWebViewControlUnviewableContentIdentifiedEventArgs) -> WinRT_String: ...
    MediaType = property(get_MediaType, None)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class WebViewControlWebResourceRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.UI.IWebViewControlWebResourceRequestedEventArgs
    _classid_ = 'Windows.Web.UI.WebViewControlWebResourceRequestedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Web.UI.IWebViewControlWebResourceRequestedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Web.UI.IWebViewControlWebResourceRequestedEventArgs) -> win32more.Windows.Web.Http.HttpRequestMessage: ...
    @winrt_mixinmethod
    def put_Response(self: win32more.Windows.Web.UI.IWebViewControlWebResourceRequestedEventArgs, value: win32more.Windows.Web.Http.HttpResponseMessage) -> Void: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Windows.Web.UI.IWebViewControlWebResourceRequestedEventArgs) -> win32more.Windows.Web.Http.HttpResponseMessage: ...
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)


make_ready(__name__)
